"""Suite of ODE solvers implemented in Python."""
from .dde_ivp import solve_ddeivp
from .rk import RK23, RK45

from .common import OdeSolution
from .base import DenseOutput, OdeSolver
print('__init__')


from setuptools import setup, find_packages

setup(
    name="dde_ivp",
    version="0.1.2",
    author="Dhamdhawach  Horsuwan",
    author_email="meng.inventor@gmail.com",
    description="A package for solving delay differential equations",
    long_description=open("README.md").read(),  # Read from README.md
    long_description_content_type="text/markdown",  # Specify Markdown format
    packages=find_packages(),
    install_requires=[
        "numpy",
        "matplotlib",
        "scipy",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
